# !/usr/bin/python
# coding=utf-8
from pythontk.core import *
from pythontk.File import File
from pythontk.Img import Img
from pythontk.Iter import Iter
from pythontk.Json import Json
from pythontk.Math import Math
from pythontk.Str import Str


name = 'pythontk'
__version__ = '0.5.4'

# --------------------------------------------------------------------------------------------






# print (__name__) #module name
# --------------------------------------------------------------------------------------------
# Notes
# --------------------------------------------------------------------------------------------


# --------------------------------------------------------------------------------------------
# deprecated:
# --------------------------------------------------------------------------------------------
